home | help
SCRM(1) 		     General Commands Manual			 SCRM(1)

NAME
     scrm - An accurate coalescent simulator for genome-scale sequences

SYNOPSIS
     scrm  nsamp  nloci [-hvL] [-r rec L [-l l] [-sr b rec]... ] [-I npop s1 ...
     sn [M] [-eI t s1 ... sn [M]]...  [-M M] [-eM t M]...  [-m i j M] [-em t i j
     M]...  [-ma M11 M21 ... Mnn] [-ema t M11 M21 ... Mnn]...  [-es  t	i  p]...
     [-ej t i j]...]  [-n i n] [-en t i n]...  [-eN t i n]...  [-g i a] [-eg t i
     a]...   [-G  t a] [-eG t a]...  [-t theta [-oSFS] [-st b theta]... ] [-seed
     seed [seed2 seed3]] [-p digits]

DESCRIPTION
     scrm is a coalescent simulator for biological sequences. Different to simi-
     lar programs, it can approximate the Ancestral Recombination Graph with ar-
     bitrary precision. This allows you to rapidly simulate long sequences  with
     essentially correct genetic linkage between sites.

OPTIONS
   Recombination:
     -r R L
	    Set recombination rate to R and locus length to L.

     -sr p R
	    Change the recombination rate R at sequence position p.

     -l l   Set the approximation window length to l.

   Population Structure:
     -I npop s1 ... sn [M]
	    Use an island model with npop populations,

	    where  s1 to sn individuals are sampled each population.  Optionally
	    assume a symmetric migration rate of M.

     -eI t s1 ... sn [M]
	    Sample s1 to sn indiviuals from their

	    corresponding populations at time t.

     -M M   Assume a symmetric migration rate of M/(npop-1).

     -eM t M
	    Change the symmetric migration rate to M/(npop-1) at time t.

     -m i j M
	    Set the migration rate from population j to population i to M

     -em t i j M
	    Set the migration rate from population j to

	    population i to M at time t.

     -ma M11 M21 ...
	    Sets the (backwards) migration matrix.

     -ema t M11 M21 ...
	    Changes the migration matrix at time t

     -es t i p
	    Population admixture. Replaces a fraction of  1-p  of  population  i
	    with  individuals a from population npop + 1 which is ignored after-
	    wards (forward in time).

     -ej t i j
	    Speciation event at time t. Creates population j from individuals of
	    population i.

   Population Size Changes:
     -n i n
	    Set the present day size of population i to n*N0.

     -en t i n
	    Change the size of population i to n*N0 at time t.

     -eN t n
	    Set the present day size of all populations to n*N0.

     -g i a
	    Set the exponential growth rate of population i to a.

     -eg t i a
	    Change the exponential growth rate of population i to a at time t.

     -G a   Set the exponential growth rate of all populations to a.

     -eG t a
	    Change the exponential growth rate of all populations to a	at  time
	    t.

   Summary Statistics:
     -t THETA
	    Set the mutation rate to THETA = 4N_0u, where u is the neutral muta-
	    tion rate per locus.

     -T     Print the local genealogies in newick format.

     -O     Print the local genealogies in the Oriented Forest format.

     -L     Print the TMRCA and the local tree length for each segment.

     -oSFS  Print  the	site  frequency  spectrum.  Requires to set the mutation
	    rate.

     -SC [ms|rel|abs]
	    Scaling of sequence positions. Either relative to the  locus  length
	    between 0 and 1 (rel), absolute in base pairs (abs) or ms-like (ms).

   Other:
     -seed SEED [SEED2 SEED3]
	    The random seed to use. Takes up three integer numbers.

     -v, --version
	    Prints the version of scrm.

     -h, --help
	    Prints this text.

     -p digits
	    Number of significant digits used in output.

Examples
   Five independent sites for 10 individuals using Kingman's Coalescent:
	    scrm 10 5 -t 10

   A sequence of 10kb from 4 individuals under the exact ARG:
	    scrm 4 1 -t 10 -r 4 10000

   A sequence of 100Mb using the SMC' approximation:
	    scrm 4 1 -t 10 -r 4000 100000000 -l 0

   Same as above, but with essentially correct linkage:
	    scrm 4 1 -t 10 -r 4000 100000000 -l 300000

Version 1.7.2			   April 2016				 SCRM(1)

home | help